***********
Fuzzy Logic
***********

This is the implementation of the methodoogy proposed by Timms 2011, Morello 2011 and Morello 2014. 
If interested in this technique, I strongly recommend you to read those articles. 
Figure 6 of Morello 2014 values a thousand words.
